# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from azure.mgmt.security.models import SecurityContact, AutoProvision

# --------------------------------------------------------------------------------------------
# Security Tasks
# --------------------------------------------------------------------------------------------


def list_security_tasks(client, resource_group_name=None):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    if resource_group_name:
        return client.tasks.list_by_resource_group(resource_group_name)

    return client.tasks.list()


def get_security_task(client, resource_name, resource_group_name=None):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    if resource_group_name:
        return client.tasks.get_resource_group_level_task(resource_group_name, resource_name)

    return client.tasks.get_subscription_level_task(resource_name)


# --------------------------------------------------------------------------------------------
# Security Alerts
# --------------------------------------------------------------------------------------------

def list_security_alerts(client, resource_group_name=None, location=None):

    if location:
        client.config.asc_location = location

        if resource_group_name:
            return client.list_resource_group_level_alerts_by_region(resource_group_name)

        return client.list_subscription_level_alerts_by_region()

    if resource_group_name:
        return client.list_by_resource_group(resource_group_name)

    return client.list()


def get_security_alert(client, location, resource_name, resource_group_name=None):

    client.config.asc_location = location

    if resource_group_name:
        return client.get_resource_group_level_alerts(resource_name, resource_group_name)

    return client.get_subscription_level_alert(resource_name)


def update_security_alert(client, location, resource_name, status, resource_group_name=None):

    client.config.asc_location = location

    if resource_group_name:
        client.update_resource_group_level_alert_state(resource_name, status, resource_group_name)
    else:
        client.update_subscription_level_alert_state(resource_name, status)


# --------------------------------------------------------------------------------------------
# Security Settings
# --------------------------------------------------------------------------------------------


def list_security_settings(client):

    return client.list()


def get_security_setting(client, resource_name):

    return client.get(resource_name)


# --------------------------------------------------------------------------------------------
# Security Contacts
# --------------------------------------------------------------------------------------------


def list_security_contacts(client):

    return client.list()


def get_security_contact(client, resource_name):

    return client.get(resource_name)


def create_security_contact(client, resource_name, email, phone=None, alert_notifications=None, alerts_admins=None):

    if alert_notifications is None:
        alert_notifications = ''

    if alerts_admins is None:
        alerts_admins = ''

    if phone is None:
        phone = ''

    new_contact = SecurityContact(email=email,
                                  phone=phone,
                                  alert_notifications=alert_notifications,
                                  alerts_to_admins=alerts_admins)

    return client.create(resource_name, new_contact)


def delete_security_contact(client, resource_name):

    return client.delete(resource_name)


# --------------------------------------------------------------------------------------------
# Security Automatic Provisioning Settings
# --------------------------------------------------------------------------------------------

def list_security_auto_provisioning_settings(client):

    return client.list()


def get_security_auto_provisioning_setting(client, resource_name):

    return client.get(resource_name)


def update_security_auto_provisioning_setting(client, auto_provision, resource_name):

    new_auto_provision = AutoProvision(auto_provision)
    return client.create(resource_name, new_auto_provision)


def turn_off_security_auto_provisioning_setting(client, resource_name):

    new_auto_provision = AutoProvision('Off')
    return client.create(resource_name, new_auto_provision)


# --------------------------------------------------------------------------------------------
# Discovered Security Solutions
# --------------------------------------------------------------------------------------------

def list_security_discovered_security_solutions(client):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    return client.discovered_security_solutions.list()


def get_security_discovered_security_solution(client, resource_name, resource_group_name):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    return client.discovered_security_solutions.get(resource_group_name, resource_name)


# --------------------------------------------------------------------------------------------
# External Security Solutions
# --------------------------------------------------------------------------------------------

def list_security_external_security_solutions(client):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    return client.external_security_solutions.list()


def get_security_external_security_solution(client, resource_name, resource_group_name):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    return client.external_security_solutions.get(resource_group_name, resource_name)


# --------------------------------------------------------------------------------------------
# Just in Time network access policies
# --------------------------------------------------------------------------------------------

def list_security_jit_network_access_policies(client, resource_group_name=None, location=None):

    if location:
        client.config.asc_location = location

        if resource_group_name:
            return client.list_by_resource_group_and_region(resource_group_name)

        return client.list_by_region()

    if resource_group_name:
        return client.list_by_resource_group(resource_group_name)

    return client.list()


def get_security_jit_network_access_policy(client, location, resource_name, resource_group_name):

    client.config.asc_location = location

    return client.get(resource_group_name, resource_name)


# --------------------------------------------------------------------------------------------
# Security Locations
# --------------------------------------------------------------------------------------------

def list_security_locations(client):

    return client.list()


def get_security_location(client, resource_name):

    client.config.asc_location = resource_name

    return client.get()


# --------------------------------------------------------------------------------------------
# Security Pricings
# --------------------------------------------------------------------------------------------

def list_security_pricings(client):

    return client.list()


def get_security_pricing(client, resource_name, resource_group_name=None):

    if resource_group_name:
        return client.get_resource_group_pricing(resource_group_name, resource_name)

    return client.get_subscription_pricing(resource_name)


def create_security_pricing(client, resource_name, tier, resource_group_name=None):

    if resource_group_name:
        return client.create_or_update_resource_group_pricing(resource_group_name, resource_name, tier)

    return client.update_subscription_pricing(resource_name, tier)


# --------------------------------------------------------------------------------------------
# Security Topology
# --------------------------------------------------------------------------------------------


def list_security_topology(client):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    return client.topology.list()


def get_security_topology(client, resource_name, resource_group_name):

    for loc in client.locations.list():
        client.config.asc_location = loc.name

    return client.topology.get(resource_group_name, resource_name)


# --------------------------------------------------------------------------------------------
# Security Topology
# --------------------------------------------------------------------------------------------


def list_security_workspace_settings(client):

    return client.list()


def get_security_workspace_setting(client, resource_name):

    return client.get(resource_name)


def create_security_workspace_setting(client, resource_name, target_workspace):

    scope = '/subscriptions/' + client.config.subscription_id
    return client.create(resource_name, target_workspace, scope)


def delete_security_workspace_setting(client, resource_name):

    client.delete(resource_name)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------


def _cf_security(cli_ctx, **_):
    from azure.cli.core.commands.client_factory import get_mgmt_service_client
    from azure.mgmt.security import SecurityCenter

    return get_mgmt_service_client(cli_ctx, SecurityCenter, asc_location="centralus")


def cf_security_tasks(cli_ctx, _):
    # do not return cli_ctx.tasks for home region compatibility
    return _cf_security(cli_ctx)


def cf_security_alerts(cli_ctx, _):
    return _cf_security(cli_ctx).alerts


def cf_security_settings(cli_ctx, _):
    return _cf_security(cli_ctx).settings


def cf_security_contacts(cli_ctx, _):
    return _cf_security(cli_ctx).security_contacts


def cf_security_auto_provisioning_settings(cli_ctx, _):
    return _cf_security(cli_ctx).auto_provisioning_settings


def cf_security_discovered_security_solutions(cli_ctx, _):
    # do not return cli_ctx.discovered_security_solutions for home region compatibility
    return _cf_security(cli_ctx)


def cf_security_external_security_solutions(cli_ctx, _):
    # do not return cli_ctx.external_security_solutions for home region compatibility
    return _cf_security(cli_ctx)


def cf_security_jit_network_access_policies(cli_ctx, _):
    return _cf_security(cli_ctx).jit_network_access_policies


def cf_security_locations(cli_ctx, _):
    return _cf_security(cli_ctx).locations


def cf_security_pricings(cli_ctx, _):
    return _cf_security(cli_ctx).pricings


def cf_security_topology(cli_ctx, _):
    # do not return cli_ctx.topology for home region compatibility
    return _cf_security(cli_ctx)


def cf_security_workspace_settings(cli_ctx, _):
    return _cf_security(cli_ctx).workspace_settings



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.help_files import helps

helps['security'] = """
    type: group
    short-summary: Manage your security posture with Azure Security Center.
"""
helps['security task'] = """
    type: group
    short-summary: View security tasks (recommendations).
"""
helps['security task list'] = """
    type: command
    short-summary: List security tasks (recommendations).
    examples:
        - name: Get security tasks (recommendations) on a subscription scope.
          text: >
              az security task list
        - name: Get security tasks (recommendations) on a resource group scope.
          text: >
              az security task list -g "myRg"
"""
helps['security task show'] = """
    type: command
    short-summary: shows a security task (recommendation).
    examples:
        - name: Get a security task (recommendation) on a subscription scope.
          text: >
              az security task show -n "taskName"
        - name: Get a security task (recommendation) on a resource group scope.
          text: >
              az security task show -g "myRg" -n "taskName"
"""
helps['security alert'] = """
    type: group
    short-summary: View security alerts.
"""
helps['security alert list'] = """
    type: command
    short-summary: List security alerts.
    examples:
        - name: Get security alerts on a subscription scope.
          text: >
              az security alert list
        - name: Get security alerts on a resource group scope.
          text: >
              az security alert list -g "myRg"
"""
helps['security alert show'] = """
    type: command
    short-summary: Shows a security alert.
    examples:
        - name: Get a security alert on a subscription scope.
          text: >
              az security alert show --location "centralus" -n "alertName"
        - name: Get a security alert on a resource group scope.
          text: >
              az security alert show -g "myRg" --location "centralus" -n "alertName"
"""
helps['security alert update'] = """
    type: command
    short-summary: Updates a security alert status.
    examples:
        - name: Dismiss a security alert on a subscription scope.
          text: >
              az security alert update --location "centralus" -n "alertName" --status "dismiss"
        - name: Dismiss a security alert on a resource group scope.
          text: >
              az security alert update -g "myRg" --location "centralus" -n "alertName" --status "dismiss"
        - name: Activate a security alert on a subscritpion scope.
          text: >
              az security alert update --location "centralus" -n "alertName" --status "activate"
        - name: Activate a security alert on a resource group scope.
          text: >
              az security alert update -g "myRg" --location "centralus" -n "alertName" --status "activate"
"""
helps['security setting'] = """
    type: group
    short-summary: View your security settings.
"""
helps['security setting list'] = """
    type: command
    short-summary: List security settings.
    examples:
        - name: Get security settings.
          text: >
              az security setting list
"""
helps['security setting show'] = """
    type: command
    short-summary: Shows a security setting.
    examples:
        - name: Get a security setting.
          text: >
              az security setting show -n "MCAS"
"""
helps['security contact'] = """
    type: group
    short-summary: View your security contacts.
"""
helps['security contact list'] = """
    type: command
    short-summary: List security contact.
    examples:
        - name: Get security contacts.
          text: >
              az security contact list
"""
helps['security contact show'] = """
    type: command
    short-summary: Shows a security contact.
    examples:
        - name: Get a security contact.
          text: >
              az security contact show -n "default1"
"""
helps['security contact create'] = """
    type: command
    short-summary: Creates a security contact.
    examples:
        - name: Creates a security contact.
          text: >
              az security contact create -n "default1" --email 'john@contoso.com' --phone '(214)275-4038' --alert-notifications 'on' --alerts-admins 'on'
"""
helps['security contact delete'] = """
    type: command
    short-summary: Deletes a security contact.
    examples:
        - name: Deletes a security contact.
          text: >
              az security contact delete -n "default1"
"""
helps['security auto-provisioning-setting'] = """
    type: group
    short-summary: View your auto provisioning settings.
"""
helps['security auto-provisioning-setting list'] = """
    type: command
    short-summary: List the auto provisioning settings.
    examples:
        - name: Get auto provisioning settings.
          text: >
              az security auto-provisioning-setting list
"""
helps['security auto-provisioning-setting show'] = """
    type: command
    short-summary: Shows an auto provisioning setting.
    examples:
        - name: Get an auto provisioning setting.
          text: >
              az security auto-provisioning-setting show -n "default"
"""
helps['security auto-provisioning-setting update'] = """
    type: command
    short-summary: Updates your automatic provisioning settings on the subscription.
    examples:
        - name: Turns on automatic provisioning on the subscription.
          text: >
              az security auto-provisioning-setting update -n "default" --auto-provision "on"
        - name: Turns off automatic provisioning on the subscription.
          text: >
              az security auto-provisioning-setting update -n "default" --auto-provision "off"
"""
helps['security discovered-security-solution'] = """
    type: group
    short-summary: View your discovered security solutions
"""
helps['security discovered-security-solution list'] = """
    type: command
    short-summary: List the discovered security solutions.
    examples:
        - name: Get discovered security solutions.
          text: >
              az security discovered-security-solution list
"""
helps['security discovered-security-solution show'] = """
    type: command
    short-summary: Shows a discovered security solution.
    examples:
        - name: Get a discovered security solution.
          text: >
              az security discovered-security-solution show -n ContosoWAF2 -g myService1
"""
helps['security external-security-solution'] = """
    type: group
    short-summary: View your external security solutions
"""
helps['security external-security-solution list'] = """
    type: command
    short-summary: List the external security solutions.
    examples:
        - name: Get external security solutions.
          text: >
              az security external-security-solution list
"""
helps['security external-security-solution show'] = """
    type: command
    short-summary: Shows an external security solution.
    examples:
        - name: Get an external security solution.
          text: >
              az security external-security-solution show -n aad_defaultworkspace-20ff7fc3-e762-44dd-bd96-b71116dcdc23-eus -g defaultresourcegroup-eus
"""
helps['security jit-policy'] = """
    type: group
    short-summary: Manage your Just in Time network access policies
"""
helps['security jit-policy list'] = """
    type: command
    short-summary: List your Just in Time network access policies.
    examples:
        - name: Get all the Just in Time network access policies.
          text: >
              az security jit-policy list
"""
helps['security jit-policy show'] = """
    type: command
    short-summary: Shows a Just in Time network access policy.
    examples:
        - name: Get a Just in Time network access policy.
          text: >
              az security jit-policy show -l northeurope -n default -g myService1
"""
helps['security location'] = """
    type: group
    short-summary: Shows the Azure Security Center Home region location.
"""
helps['security location list'] = """
    type: command
    short-summary: Shows the Azure Security Center Home region location.
    examples:
        - name: Shows the Azure Security Center Home region location.
          text: >
              az security location list
"""
helps['security location show'] = """
    type: command
    short-summary: Shows the Azure Security Center Home region location.
    examples:
        - name: Shows the Azure Security Center Home region location.
          text: >
              az security location show -n centralus
"""
helps['security pricing'] = """
    type: group
    short-summary: Shows the Azure Security Center Pricing tier for the subscription.
"""
helps['security pricing list'] = """
    type: command
    short-summary: Shows the Azure Security Center Pricing tier for the subscription.
    examples:
        - name: Shows the Azure Security Center Pricing tier for the subscription.
          text: >
              az security pricing list
"""
helps['security pricing show'] = """
    type: command
    short-summary: Shows the Azure Security Center Pricing tier for the subscription.
    examples:
        - name: Shows the Azure Security Center Pricing tier for the subscription.
          text: >
              az security pricing show -n default
"""
helps['security pricing create'] = """
    type: command
    short-summary: Updates the Azure Security Center Pricing tier for the subscription.
    examples:
        - name: Updates the Azure Security Center Pricing tier for the subscription.
          text: >
              az security pricing create -n default --tier 'standard'
"""
helps['security topology'] = """
    type: group
    short-summary: Shows the network topology in your subscription.
"""
helps['security topology list'] = """
    type: command
    short-summary: Shows the network topology in your subscription.
    examples:
        - name: Shows the network topology in your subscription.
          text: >
              az security topology list
"""
helps['security topology show'] = """
    type: command
    short-summary: Shows the network topology in your subscription.
    examples:
        - name: Shows the network topology in your subscription.
          text: >
              az security topology show -n default -g myService1
"""
helps['security workspace-setting'] = """
    type: group
    short-summary: Shows the workspace settings in your subscription - these settings let you control which workspace will hold your security data
"""
helps['security workspace-setting list'] = """
    type: command
    short-summary: Shows the workspace settings in your subscription - these settings let you control which workspace will hold your security data
    examples:
        - name: Shows the workspace settings in your subscription - these settings let you control which workspace will hold your security data
          text: >
              az security workspace-setting list
"""
helps['security workspace-setting show'] = """
    type: command
    short-summary: Shows the workspace settings in your subscription - these settings let you control which workspace will hold your security data
    examples:
        - name: Shows the workspace settings in your subscription - these settings let you control which workspace will hold your security data
          text: >
              az security workspace-setting show -n default
"""
helps['security workspace-setting create'] = """
    type: command
    short-summary: Creates a workspace settings in your subscription - these settings let you control which workspace will hold your security data
    examples:
        - name: Creates a workspace settings in your subscription - these settings let you control which workspace will hold your security data
          text: >
              az security workspace-setting create -n default --target-workspace '/subscriptions/20ff7fc3-e762-44dd-bd96-b71116dcdc23/resourceGroups/myRg/providers/Microsoft.OperationalInsights/workspaces/myWorkspace'
"""
helps['security workspace-setting delete'] = """
    type: command
    short-summary: Deletes the workspace settings in your subscription - this will make the security events on the subscription be reported to the default workspace
    examples:
        - name: Deletes the workspace settings in your subscription - this will make the security events on the subscription be reported to the default workspace
          text: >
              az security workspace-setting delete -n default
"""



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.util import CLIError


def validate_alert_status(namespace):
    lower_status = namespace.status.lower()
    if lower_status not in ['dismiss', 'activate']:
        raise CLIError('--status can only accept "dismiss" or "activate" values')


def validate_auto_provisioning_toggle(namespace):
    lower_toggle = namespace.auto_provision.lower()
    if lower_toggle not in ['on', 'off']:
        raise CLIError('--auto-provision can only accept "on" or "off" values')


def validate_pricing_tier(namespace):
    pricing_tier = namespace.tier.lower()
    if pricing_tier not in ['free', 'standard']:
        raise CLIError('--tier can only accept "standard" or "free" values')



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from azure.cli.core.commands import CliCommandType
from ._client_factory import (cf_security_tasks,
                              cf_security_alerts,
                              cf_security_settings,
                              cf_security_contacts,
                              cf_security_auto_provisioning_settings,
                              cf_security_discovered_security_solutions,
                              cf_security_external_security_solutions,
                              cf_security_jit_network_access_policies,
                              cf_security_locations,
                              cf_security_pricings,
                              cf_security_topology,
                              cf_security_workspace_settings)


# pylint: disable=line-too-long
# pylint: disable=too-many-statements
def load_command_table(self, _):

    security_tasks_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#TasksOperations.{}',
        client_factory=cf_security_tasks,
        operation_group='security_tasks'
    )

    security_alerts_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#AlertsOperations.{}',
        client_factory=cf_security_alerts,
        operation_group='security_alerts'
    )

    security_settings_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#SettingsOperations.{}',
        client_factory=cf_security_settings,
        operation_group='security_settings'
    )

    security_contacts_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#SecurityContactsOperations.{}',
        client_factory=cf_security_contacts,
        operation_group='security_contacts'
    )

    security_auto_provisioning_settings_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#AutoProvisioningSettingsOperations.{}',
        client_factory=cf_security_auto_provisioning_settings,
        operation_group='security_auto_provisioning_settings'
    )

    security_discovered_security_solutions_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#DiscoveredSecuritySolutionsOperations.{}',
        client_factory=cf_security_discovered_security_solutions,
        operation_group='security_discovered_security_solutions'
    )

    security_external_security_solutions_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#ExternalSecuritySolutionsOperations.{}',
        client_factory=cf_security_external_security_solutions,
        operation_group='security_external_security_solutions'
    )

    security_jit_network_access_policies_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#JitNetworkAccessPoliciesOperations.{}',
        client_factory=cf_security_jit_network_access_policies,
        operation_group='security_jit_network_access_policies'
    )

    security_locations_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#LocationsOperations.{}',
        client_factory=cf_security_locations,
        operation_group='security_locations'
    )

    security_pricings_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#PricingsOperations.{}',
        client_factory=cf_security_pricings,
        operation_group='security_pricings'
    )

    security_topology_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#TopologyOperations.{}',
        client_factory=cf_security_topology,
        operation_group='security_topology'
    )

    security_workspace_settings_sdk = CliCommandType(
        operations_tmpl='azure.mgmt.security.operations#WorkspaceSettingsOperations.{}',
        client_factory=cf_security_workspace_settings,
        operation_group='security_workspace_settings'
    )

    with self.command_group('security task',
                            security_tasks_sdk,
                            client_factory=cf_security_tasks) as g:
        g.custom_command('list', 'list_security_tasks')
        g.custom_command('show', 'get_security_task')

    with self.command_group('security alert',
                            security_alerts_sdk,
                            client_factory=cf_security_alerts) as g:
        g.custom_command('list', 'list_security_alerts')
        g.custom_command('show', 'get_security_alert')
        g.custom_command('update', 'update_security_alert')

    with self.command_group('security setting',
                            security_settings_sdk,
                            client_factory=cf_security_settings) as g:
        g.custom_command('list', 'list_security_settings')
        g.custom_command('show', 'get_security_setting')

    with self.command_group('security contact',
                            security_contacts_sdk,
                            client_factory=cf_security_contacts) as g:
        g.custom_command('list', 'list_security_contacts')
        g.custom_command('show', 'get_security_contact')
        g.custom_command('create', 'create_security_contact')
        g.custom_command('delete', 'delete_security_contact')

    with self.command_group('security auto-provisioning-setting',
                            security_auto_provisioning_settings_sdk,
                            client_factory=cf_security_auto_provisioning_settings) as g:
        g.custom_command('list', 'list_security_auto_provisioning_settings')
        g.custom_command('show', 'get_security_auto_provisioning_setting')
        g.custom_command('update', 'update_security_auto_provisioning_setting')

    with self.command_group('security discovered-security-solution',
                            security_discovered_security_solutions_sdk,
                            client_factory=cf_security_discovered_security_solutions) as g:
        g.custom_command('list', 'list_security_discovered_security_solutions')
        g.custom_command('show', 'get_security_discovered_security_solution')

    with self.command_group('security external-security-solution',
                            security_external_security_solutions_sdk,
                            client_factory=cf_security_external_security_solutions) as g:
        g.custom_command('list', 'list_security_external_security_solutions')
        g.custom_command('show', 'get_security_external_security_solution')

    with self.command_group('security jit-policy',
                            security_jit_network_access_policies_sdk,
                            client_factory=cf_security_jit_network_access_policies) as g:
        g.custom_command('list', 'list_security_jit_network_access_policies')
        g.custom_command('show', 'get_security_jit_network_access_policy')

    with self.command_group('security location',
                            security_locations_sdk,
                            client_factory=cf_security_locations) as g:
        g.custom_command('list', 'list_security_locations')
        g.custom_command('show', 'get_security_location')

    with self.command_group('security pricing',
                            security_pricings_sdk,
                            client_factory=cf_security_pricings) as g:
        g.custom_command('list', 'list_security_pricings')
        g.custom_command('show', 'get_security_pricing')
        g.custom_command('create', 'create_security_pricing')

    with self.command_group('security topology',
                            security_topology_sdk,
                            client_factory=cf_security_topology) as g:
        g.custom_command('list', 'list_security_topology')
        g.custom_command('show', 'get_security_topology')

    with self.command_group('security workspace-setting',
                            security_workspace_settings_sdk,
                            client_factory=cf_security_workspace_settings) as g:
        g.custom_command('list', 'list_security_workspace_settings')
        g.custom_command('show', 'get_security_workspace_setting')
        g.custom_command('create', 'create_security_workspace_setting')
        g.custom_command('delete', 'delete_security_workspace_setting')



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

# pylint: disable=line-too-long

from azure.cli.core.commands.parameters import resource_group_name_type
from knack.arguments import CLIArgumentType
from ._validators import (validate_alert_status,
                          validate_auto_provisioning_toggle,
                          validate_pricing_tier)

name_arg_type = CLIArgumentType(options_list=('--name', '-n'), metavar='NAME', help='name of the resource to be fetched')
home_region_arg_type = CLIArgumentType(options_list=('--home-region', '-hr'), metavar='HOMEREGION', help='home region that was selected for the subscription')
location_arg_type = CLIArgumentType(options_list=('--location', '-l'), metavar='LOCATION', help='location of the resource')

# Alerts
alert_status_arg_type = CLIArgumentType(options_list=('--status'), metavar='STATUS', help='target status of the alert. possible values are "dismiss" and "activate"')

# Auto Provisioning
auto_provisioning_auto_provision_arg_type = CLIArgumentType(options_list=('--auto-provision'), metavar='AUTOPROVISION', help='Automatic provisioning toggle. possible values are "on" or "off"')

# Contacts
contact_email_arg_type = CLIArgumentType(options_list=('--email'), metavar='EMAIL', help='E-mail of the security contact')
contact_phone_arg_type = CLIArgumentType(options_list=('--phone'), metavar='PHONE', help='Phone of the security contact')
contact_alert_notifications_arg_type = CLIArgumentType(options_list=('--alert-notifications'), metavar='ALERTNOTIFICATIONS', help='Whether to send mail notifications to the security contacts')
contact_alerts_admins_arg_type = CLIArgumentType(options_list=('--alerts-admins'), metavar='ALERTADMINS', help='Whether to send mail notifications to the subscription administrators')

# Pricing
pricing_tier_arg_type = CLIArgumentType(options_list=('--tier'), metavar='TIER', help='pricing tier type')

# Workspace settings
workspace_setting_target_workspace_arg_type = CLIArgumentType(options_list=('--target-workspace'), metavar='TARGETWORKSPACE', help='An ID of the workspace resource that will hold the security data')


def load_arguments(self, _):
    for scope in ['alert',
                  'task',
                  'setting',
                  'contact',
                  'auto-provisioning-setting',
                  'discovered-security-solution',
                  'external-security-solution',
                  'jit-policy',
                  'location',
                  'pricing',
                  'topology',
                  'workspace-setting']:
        with self.argument_context('security {}'.format(scope)) as c:
            c.argument(
                'resource_group_name',
                options_list=['--resource-group', '-g'],
                arg_type=resource_group_name_type)
            c.argument(
                'resource_name',
                arg_type=name_arg_type)
            c.argument(
                'location',
                arg_type=location_arg_type)

    for scope in ['alert update']:
        with self.argument_context('security {}'.format(scope)) as c:
            c.argument(
                'status',
                validator=validate_alert_status,
                arg_type=alert_status_arg_type)

    for scope in ['auto-provisioning-setting update']:
        with self.argument_context('security {}'.format(scope)) as c:
            c.argument(
                'auto_provision',
                validator=validate_auto_provisioning_toggle,
                arg_type=auto_provisioning_auto_provision_arg_type)

    for scope in ['contact create']:
        with self.argument_context('security {}'.format(scope)) as c:
            c.argument(
                'email',
                arg_type=contact_email_arg_type)
            c.argument(
                'phone',
                arg_type=contact_phone_arg_type)
            c.argument(
                'alert_notifications',
                arg_type=contact_alert_notifications_arg_type)
            c.argument(
                'alerts_admins',
                arg_type=contact_alerts_admins_arg_type)

    for scope in ['pricing create']:
        with self.argument_context('security {}'.format(scope)) as c:
            c.argument(
                'tier',
                validator=validate_pricing_tier,
                arg_type=pricing_tier_arg_type)

    for scope in ['workspace-setting create']:
        with self.argument_context('security {}'.format(scope)) as c:
            c.argument(
                'target_workspace',
                arg_type=workspace_setting_target_workspace_arg_type)
